import urlTransform from '@/webPublic/zyd_public/request/urlTransform';
import FormdataWrapper from '@/webPublic/zyd_public/utils/object-to-formdata-custom';
import { notification } from 'antd';
import { getHeaders, getIsBei_Dian } from '@/webPublic/zyd_public/utils/utils';

/**
 * 本地开发可能会存在跨域问题
 * 只能用于学工的接口的下载文件
 * */
export function downloadFile(url, params, fileName = '导出文件', ext = 'xlsx', method = 'POST') {
  if (process.env.NODE_ENV === 'development' && getIsBei_Dian()) {
    url = url.replace('https://yx.bpi.edu.cn/produce', 'http://localhost:8010/produce');
    url = url.replace('http://scjoyedu.eicp.net:51352/produce', 'http://localhost:8010/produce');
  }
  url = urlTransform(url);

  fetch(url, {
    method,
    body: method === 'GET' ? undefined : FormdataWrapper(params),
    ...getHeaders(),
  })
    .then((res) => {
      if (res.status + '' !== '200') {
        return res.json();
      } else {
        const contentDisposition = res.headers.get('content-disposition');
        let fileNameEncode = contentDisposition && contentDisposition.split('filename=');
        if(fileNameEncode.length > 1){
          fileNameEncode = fileNameEncode[1];
          fileName = decodeURIComponent(fileNameEncode);
          console.log('fileName', fileName);
        }
        // 解码
        return res.blob();
      }
    })
    .then((data) => {
      if (data instanceof Blob) {
        let a = document.createElement('a');
        let url = window.URL.createObjectURL(data);
        let filename = fileName + '.' + ext;
        a.href = url;
        a.download = filename;
        a.click();
        window.URL.revokeObjectURL(url);
        a = null;
      } else {
        notification.error({
          message: `文件导出错误`,
          description: data.errMsg,
        });
      }
    })
    .catch((err) => {
      console.log(err);
      notification.error({
        message: `网络请求超时`,
      });
    })
    .finally(() => {
      return true;
    });
}
